@@ -1243,11 +1243,9 @@ def __develop(encodings):
 
 
 def __guess(prev_input, input, stop_func, depth, max_depth, min_depth, codec_categories, exclude, result, found=(),
-            stop=True, show=False, scoring_heuristic=False, extended=False, debug=False, regex=False):
+            stop=True, show=False, scoring_heuristic=False, extended=False, debug=False):
     """ Perform a breadth-first tree search using a ranking logic to select and prune the list of codecs. """
     if depth > min_depth and stop_func(input):
-        if regex:
-            stop = True
         if not stop and (show or debug) and found not in result:
             s = repr(input)
             s = s[2:-1] if s.startswith("b'") and s.endswith("'") else s
@@ -1288,7 +1286,7 @@ def __guess(prev_input, input, stop_func, depth, max_depth, min_depth, codec_cat
         if debug:
             print("[*] Depth %0{}d/%d: %s".format(len(str(max_depth))) % (depth+1, max_depth, encoding))
         __guess(input, new_input, stop_func, depth+1, max_depth, min_depth, codec_categories, exclude, result,
-                found + (encoding, ), stop, show, scoring_heuristic, extended, debug, regex)
+                found + (encoding, ), stop, show, scoring_heuristic, extended, debug)
 
 
 def __rank(prev_input, input, prev_encoding, codecs, heuristic=False, extended=False, yield_score=False):
@@ -1305,9 +1303,13 @@ class _Text(object):
     __slots__ = ["entropy", "lcharset", "len", "padding", "printables"]
     
     def __init__(self, text, pad_char=None):
+        c = text[-1]
+        last_char = c if isinstance(c, int) else ord(c)
+        self.padding = pad_char is not None and last_char == ord(pad_char)
+        if self.padding:
+            text = text.rstrip(pad_char)
         self.len = len(text)
         self.lcharset = len(set(text))
-        self.padding = pad_char is not None and text[-1] in [pad_char, b(pad_char)]
         self.printables = float(len([c for c in text if (chr(c) if isinstance(c, int) else c) in printable])) / self.len
         self.entropy = entropy(text)
 
@@ -1365,16 +1367,16 @@ def __score(prev_input, input, prev_encoding, codec, heuristic=False, extended=F
                     s += .1
             expf = sc.get('expansion_factor', 1.)
             if expf:
-                f = float(len(new_input)) / obj.len
+                f = obj.len / float(len(new_input))  # expansion while encoding => at decoding: 1/f
                 if isinstance(expf, type(lambda: None)):
                     try:  # this case allows to consider the current encoding name from the current codec
                         expf = expf(f, encoding)
                     except TypeError:
                         expf = expf(f)
-                elif isinstance(expf, (int, float)):
-                    epxf = f - .1 <= expf <= f + .1
+                if isinstance(expf, (int, float)):
+                    expf = (1/f - .1 <= 1/expf <= 1/f + .1)
                 elif isinstance(expf, (tuple, list)) and len(expf) == 2:
-                    expf = f - expf[1] <= expf[0] <= expf[1] + .1
+                    expf = 1/f - expf[1] <= 1/expf[0] <= 1/f + expf[1]
                 s += [-1., .1][expf]
             # afterwards, if the input text has an entropy close to the expected one, give a bonus weighted on the
             #  number of input characters to take bad entropies of shorter strings into account
@@ -1414,17 +1416,15 @@ def guess(input, stop_func=stopfunc.default, min_depth=0, max_depth=5, codec_cat
     if len(found) > 0:
         for encoding in found:
             input = decode(input, encoding)
-    regex = False
     if isinstance(stop_func, string_types):
         stop_func = stopfunc.regex(stop_func)
-        regex = True
     result = {}
     if len(input) > 0:
         try:
             # breadth-first search
             for d in range(max_depth):
                 __guess("", input, stop_func, 0, d+1, min_depth, codec_categories, exclude, result, tuple(found), stop,
-                        show, scoring_heuristic, extended, debug, regex)
+                        show, scoring_heuristic, extended, debug)
                 if stop and len(result) > 0:
                     return result
         except KeyboardInterrupt:
